==> knative-model-4.9.0-sources.jar: io/fabric8/knative/duck/v1beta1/SubscriberSpecFluent.java <==
package io.fabric8.knative.duck.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.v1.URLFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.v1.URL;
import io.fabric8.knative.v1.URLBuilder;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SubscriberSpecFluent<A extends io.fabric8.knative.duck.v1beta1.SubscriberSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDelivery instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.duck.v1beta1.DeliverySpec getDelivery();
    public io.fabric8.knative.duck.v1beta1.DeliverySpec buildDelivery();
    public A withDelivery(io.fabric8.knative.duck.v1beta1.DeliverySpec delivery);
    public Boolean hasDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> withNewDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> withNewDeliveryLike(io.fabric8.knative.duck.v1beta1.DeliverySpec item);
    public SubscriberSpecFluent.DeliveryNested<A> editDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> editOrNewDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(io.fabric8.knative.duck.v1beta1.DeliverySpec item);
    public Long getGeneration();
    public A withGeneration(Long generation);
    public Boolean hasGeneration();
    
/**
 * This method has been deprecated, please use method buildReplyUri instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public URL getReplyUri();
    public URL buildReplyUri();
    public A withReplyUri(URL replyUri);
    public Boolean hasReplyUri();
    public SubscriberSpecFluent.ReplyUriNested<A> withNewReplyUri();
    public SubscriberSpecFluent.ReplyUriNested<A> withNewReplyUriLike(URL item);
    public SubscriberSpecFluent.ReplyUriNested<A> editReplyUri();
    public SubscriberSpecFluent.ReplyUriNested<A> editOrNewReplyUri();
    public SubscriberSpecFluent.ReplyUriNested<A> editOrNewReplyUriLike(URL item);
    
/**
 * This method has been deprecated, please use method buildSubscriberUri instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public URL getSubscriberUri();
    public URL buildSubscriberUri();
    public A withSubscriberUri(URL subscriberUri);
    public Boolean hasSubscriberUri();
    public SubscriberSpecFluent.SubscriberUriNested<A> withNewSubscriberUri();
    public SubscriberSpecFluent.SubscriberUriNested<A> withNewSubscriberUriLike(URL item);
    public SubscriberSpecFluent.SubscriberUriNested<A> editSubscriberUri();
    public SubscriberSpecFluent.SubscriberUriNested<A> editOrNewSubscriberUri();
    public SubscriberSpecFluent.SubscriberUriNested<A> editOrNewSubscriberUriLike(URL item);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);

    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1beta1.DeliverySpecFluent<SubscriberSpecFluent.DeliveryNested<N>>{

        
    public N and();    public N endDelivery();
}
    public interface ReplyUriNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<SubscriberSpecFluent.ReplyUriNested<N>>{

        
    public N and();    public N endReplyUri();
}
    public interface SubscriberUriNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,URLFluent<SubscriberSpecFluent.SubscriberUriNested<N>>{

        
    public N and();    public N endSubscriberUri();
}


}

==> knative-model-4.10.1-sources.jar: io/fabric8/knative/duck/v1beta1/SubscriberSpecFluent.java <==
package io.fabric8.knative.duck.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SubscriberSpecFluent<A extends io.fabric8.knative.duck.v1beta1.SubscriberSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDelivery instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.duck.v1beta1.DeliverySpec getDelivery();
    public io.fabric8.knative.duck.v1beta1.DeliverySpec buildDelivery();
    public A withDelivery(io.fabric8.knative.duck.v1beta1.DeliverySpec delivery);
    public Boolean hasDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> withNewDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> withNewDeliveryLike(io.fabric8.knative.duck.v1beta1.DeliverySpec item);
    public SubscriberSpecFluent.DeliveryNested<A> editDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> editOrNewDelivery();
    public SubscriberSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(io.fabric8.knative.duck.v1beta1.DeliverySpec item);
    public Long getGeneration();
    public A withGeneration(Long generation);
    public Boolean hasGeneration();
    public String getReplyUri();
    public A withReplyUri(String replyUri);
    public Boolean hasReplyUri();
    public A withNewReplyUri(String arg1);
    public A withNewReplyUri(StringBuilder arg1);
    public A withNewReplyUri(StringBuffer arg1);
    public String getSubscriberUri();
    public A withSubscriberUri(String subscriberUri);
    public Boolean hasSubscriberUri();
    public A withNewSubscriberUri(String arg1);
    public A withNewSubscriberUri(StringBuilder arg1);
    public A withNewSubscriberUri(StringBuffer arg1);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);

    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1beta1.DeliverySpecFluent<SubscriberSpecFluent.DeliveryNested<N>>{

        
    public N and();    public N endDelivery();
}


}
